/*
C                                                                             C
C     ---------The NNPDF polarized PARTON DISTRIBUTION FUNCTIONS---------     C
C                                                                             C
C     REFERENCE:                                                              C
C           "Unbiased determination of polarized parton distributions         C 
C            and their uncertainties" [arXiv:1303.7236]                       C
C                                                                             C
C     INPUT:                                                                  C
C           X     :  BJORKEN-X BETWEEN 10**(-5)< X < 1.0                      C
C           Q2    :  SCALE**2 IN GeV**2 BETWEEN  1 < Q**2 < 10**5 GeV**2      C
C           IREP  :  THE I-TH MONTE CARLO REPLICA OF THE ENSEMBLE             C
C                                                                             C
C     OUTPUT:                                                                 C
C           XPDF[irep]                                                        C
C           XPDF[0]  :  X * (U+UBAR) POLARIZED DISTRIBUTION                   C
C           XPDF[1]  :  X * (D+DBAR) POLARIZED DISTRIBUTION                   C
C           XPDF[2]  :  X * (S+SBAR) POLARIZED DISTRIBUTION                   C
C           XPDF[3]  :  X * GLUON POLARIZED DISTRIBUTION                      C
C                                                                             C
C     IMPORTANT:                                                              C
C           1) DOWNLOAD AND INSTALL THE LHAPDF INTERFACE FROM                 C
C                          https://lhapdf.hepforge.org/                       C
C           2) DOWNLOAD THE PROPER POLARIZED PDF GRIDS AVAILABLE AT           C
C                          https://nnpdf.hepforge.org/                        C
C              AND PUT THE .LHgrid FILE IN THE PROPER DIRECTORY               C
C              (tipically /usr/local/share/lhapdf/PDFsets/)                   C
C           3) BEFORE CALLING THE nnpdfpol FUNCTION YOU MUST INITIALIZE       C
C              THE PDF GRIDS BY CALLING (ONLY ONCE) THE PROPER function       C
C              (see the cppexample.cpp program for details)                   C
C           4) ALWAYS X*DISTRIBUTION IS RETURNED                              C
C           5) ALL PDFs ARE IN THE MSbar SCHEME                               C
C           6) THE X*DISTRIBUTION IS RETURNED FOR THE IREP-TH REPLICA IN      C
C              THE MONTE CARLO ENSEMBLE. THE REPLICA IREP=0 CORRESPONDS TO    C
C              THE MEAN VALUE COMPUTED OVER THE WHOLE MONTE CARLO ENSEMBLE    C 
C           7) MEAN VALUES AND ERRORS OF OBSERVABLES CAN BE COMPUTED WITH     C
C              THE RECIPE DESCRIBED IN APPENDIX B OF arXiv:0808.1231          C
C              (see the cppexample.cpp program for details)                   C
C                                                                             C
C     IN CASE OF PROBLEMS, DOUBTS, ETC, PLEASE E-MAIL US AT                   C
C           The NNPDF Collaboration: nnpdf@mi.infn.it                         C
C                                                                             C
*/

void nnpdfpol(double x, double Q2, int irep, double xpdf[])
{
  double Q=sqrt(Q2);
  LHAPDF::initPDF(irep);
  //x+(u+ubar)
  xpdf[0]=LHAPDF::xfx(x,Q,2)+LHAPDF::xfx(x,Q,-2);
  //x+(d+dbar)
  xpdf[1]=LHAPDF::xfx(x,Q,1)+LHAPDF::xfx(x,Q,-1);
  //x+(s+sbar)
  xpdf[2]=LHAPDF::xfx(x,Q,3)+LHAPDF::xfx(x,Q,-3);
  //x*gluon
  xpdf[3]=LHAPDF::xfx(x,Q,0);
  return;
}


