/*
  This program computes the mean value and the standard deviation
  of the x(u+ubar), x(d+dbar), x(s+sbar) and xgluon polarized pdf
  combinations at fixed energy scale q2 for different values of x
  from a Monte Carlo ensemble of polarized NNPDFs.
  Results are stores in .res files.
                                    
  If not already done, please:
  1) download and install LHAPDF interface from 
           https://lhapdf.hepforge.org/
  2) download the proper PDF set from 
           https://nnpdf.hepforge.org/
  3) put the .LHgrid file in the proper directory
     (tipically /usr/local/share/lhapdf/PDFsets/)
*/

#include <iostream>
#include <fstream>
#include <iomanip>
#include <cmath>
#include "LHAPDF/LHAPDF.h"
#include "NNPDFpol10.h"
using namespace std;

int main()
{ 
  //Energy scale at which PDFs are computed (in GeV^2)
  const double Q2 = 1.0;
  //Minimum value of x Bjorken
  const double xmin = 0.001;
  //Maximum value of x Bjorken
  const double xmax = 1.0;
  //Numeber of (linearly spaced) points in x
  const int npoints=100;
  //Set the name of the PDF grid to be initialized
  string wrapfile="NNPDFpol10_100.LHgrid";

  //Load the PDF grid from file
  LHAPDF::initPDFSet(wrapfile.c_str());

  //Initialize the number of PDF memebers in the grid
  const int nrep = LHAPDF::numberPDF();

  double deltax=(xmax-xmin)/double(npoints);
  double Q=pow(Q2,0.5);
    
  const int npdf=4;
  double xpdf[npdf];

  for(int ipdf=0; ipdf<npdf; ipdf++)
    {
      xpdf[ipdf]=0;
    }

  //Write to a file the central value of the available 
  //polarized PDFs for 100 points linearly spaced in x
  ofstream out1;
  const string outputfile="xnnpdfpol_cv_cc.res";
  out1.open(outputfile.c_str());
  for(int ipt=0; ipt<npoints+1; ipt++)
    {
      double x = xmin+ipt*deltax;
      int irep=0;// <- Replica 0 == Central Value (AVG)

      nnpdfpol(x, Q2, irep, xpdf);
      out1 << setw(5) << ipt << setiosflags(ios::fixed)
	   << setw(10) << setprecision(7) << x
	   << setw(15) << setprecision(10) << xpdf[0] 
	   << setw(15) << setprecision(10) << xpdf[1] 
	   << setw(15) << setprecision(10) << xpdf[2] 
	   << setw(15) << setprecision(10) << xpdf[3] 
	   << endl;
    }
  out1.close();

  //Write to a file the mean value and the standard deviation
  //of the available polarized PDFs for 100 points linearly 
  //spaced in x using the Monte Carlo recipe
  const string outputfile1="xnnpdfpol_cc.res";
  out1.open(outputfile1.c_str());
  for(int ipt=0; ipt<npoints+1; ipt++)
    {

      double xpdf_av[npdf], xpdf_er[npdf];

      for(int ipdf=0; ipdf<npdf; ipdf++)
	{
	  xpdf_av[ipdf]=.0;
	  xpdf_er[ipdf]=.0;
	}

      double x = xmin+ipt*deltax;
 
      for(int irep=1; irep<nrep+1; irep++)
	{
	  nnpdfpol(x, Q2, irep, xpdf);
	  
	  for(int ipdf=0; ipdf<npdf; ipdf++)
	    {
	      xpdf_av[ipdf]=xpdf_av[ipdf]+xpdf[ipdf]/double(nrep);
	      xpdf_er[ipdf]=xpdf_er[ipdf]+pow(xpdf[ipdf],2)/double(nrep);
	    }
	}

      for(int ipdf=0; ipdf<npdf; ipdf++)
	{
	  xpdf_er[ipdf]=sqrt(xpdf_er[ipdf]-pow(xpdf_av[ipdf],2));
	}

      out1 << setw(5) << ipt << setiosflags(ios::fixed)
	   << setw(10) << setprecision(7) << x  
	   << setw(15) << setprecision(10) << xpdf_av[0] 
	   << setw(15) << setprecision(10) << xpdf_er[0] 
	   << setw(15) << setprecision(10) << xpdf_av[1] 
	   << setw(15) << setprecision(10) << xpdf_er[1] 
	   << setw(15) << setprecision(10) << xpdf_av[2] 
	   << setw(15) << setprecision(10) << xpdf_er[2] 
	   << setw(15) << setprecision(10) << xpdf_av[3] 
	   << setw(15) << setprecision(10) << xpdf_er[3] 
	   << endl;

    }
  out1.close();

  return 0;
}
