CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                             C
C     ---------The NNPDF polarized PARTON DISTRIBUTION FUNCTIONS---------     C
C                                                                             C
C     REFERENCE:                                                              C
C           "Unbiased determination of polarized parton distributions         C 
C            and their uncertainties" [arXiv:1303.7236]                       C
C                                                                             C
C     INPUT:                                                                  C
C           DX     :  BJORKEN-X BETWEEN 10**(-5)< X < 1.0                     C
C           DQ2    :  SCALE**2 IN GeV**2 BETWEEN  1 < Q**2 < 10**5 GeV**2     C
C           DIREP  :  THE I-TH MONTE CARLO REPLICA OF THE ENSEMBLE            C
C                                                                             C
C     OUTPUT:                                                                 C
C           XUUBAR   :  X * (U+UBAR) POLARIZED DISTRIBUTION                   C
C           XDDBAR   :  X * (D+DBAR) POLARIZED DISTRIBUTION                   C
C           XSSBAR   :  X * (S+SBAR) POLARIZED DISTRIBUTION                   C
C           XGLUON   :  X * GLUON POLARIZED DISTRIBUTION                      C
C                                                                             C
C     IMPORTANT:                                                              C
C           1) YOU MUST HAVE DOWNLOADED THE PROPER POLARIZED PDF GRIDS        C
C              AVAILABLE AT                                                   C
C                          https://nnpdf.hepforge.org/                        C
C           2) BEFORE CALLING THE SUBROUTINE NNPDFpol YOU MUST INITIALIZE     C
C              THE PDF GRIDS BY CALLING (ONLY ONCE) THE PROPER SUBROUTINE     C
C              (see the f77example.f program for details)                     C
C           3) ALWAYS X*DISTRIBUTION IS RETURNED                              C
C           4) ALL PDFs ARE IN THE MSbar SCHEME                               C
C           5) THE X*DISTRIBUTION IS RETURNED FOR THE IREP-TH REPLICA IN      C
C              THE MONTE CARLO ENSEMBLE. THE REPLICA IREP=0 CORRESPONDS TO    C
C              THE MEAN VALUE COMPUTED OVER THE WHOLE MONTE CARLO ENSEMBLE    C 
C           6) MEAN VALUES AND ERRORS OF OBSERVABLES CAN BE COMPUTED WITH     C
C              THE RECIPE DESCRIBED IN APPENDIX B OF arXiv:0808.1231          C
C                                                                             C
C     IN CASE OF PROBLEMS, DOUBTS, ETC, PLEASE E-MAIL US AT                   C
C           The NNPDF Collaboration: nnpdf@mi.infn.it                         C
C                                                                             C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      SUBROUTINE NNPDFPOL(DX,DQ2,DIREP,XUUBAR,XDDBAR,XSSBAR,XGLUON)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT NONE

      DOUBLE PRECISION X, Q, Q2, DX, DQ2
      INTEGER IREP, DIREP
      DOUBLE PRECISION XPDFLHPOL(-6:6)
      DOUBLE PRECISION XUUBAR, XDDBAR, XSSBAR, XGLUON

      X=DX
      Q2=DQ2
      Q=DSQRT(Q2)
      IREP=DIREP

      CALL INITNNPDF(IREP)
      CALL EVOLVENNPDF(X,Q,XPDFLHPOL)
      
*     X*(U+UBAR)
      XUUBAR=XPDFLHPOL(2)+XPDFLHPOL(-2)

*     X*(D+DBAR)
      XDDBAR=XPDFLHPOL(1)+XPDFLHPOL(-1)

*     X*(S+SBAR)
      XSSBAR=XPDFLHPOL(3)+XPDFLHPOL(-3)

*     X*GLUON
      XGLUON=XPDFLHPOL(0)

      RETURN
      END

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      SUBROUTINE EVOLVENNPDF(X,Q,XPDF)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT NONE

      INTEGER MXREP
      PARAMETER(MXREP=1e3)
      INTEGER KREPWRAP,NREP
      common/CNREP/NREP
      common/CKREPWRAP/KREPWRAP

      INTEGER NPX,NPQ2,NPL,IX,IQ2
      PARAMETER(NPX=100,NPQ2=50)
      PARAMETER(NPL=5000)
      DOUBLE PRECISION Q2MIN,Q2MAX,XPDFMIN,XPDFMAX,XCH,Q2CH
      PARAMETER(Q2MAX=1d5,Q2CH=4d0)
      PARAMETER(XPDFMIN=1d-5,XPDFMAX=1d0,XCH=1D-1)

      DOUBLE PRECISION XG(NPX),Q2G(NPQ2),XPDFEV(NPX,NPQ2,-6:6,0:MXREP)
      common/CPDFGR/XPDFEV,XG,Q2G,Q2MIN,IX,IQ2
      
      INTEGER I,IPDF,KREP
      DOUBLE PRECISION X,Q,Q2,XPDF(-6:6)

*     For interpolation
      integer m,n,nmax,mmax,minq,maxq,midq,maxx,minx,midx
      parameter(m=4,n=2) 
      parameter(nmax=1e3,mmax=1e3)
      double precision dy,x1,x2,y,x1a(mmax),x2a(nmax),ya(mmax,nmax)
      integer ix1a(m),ix2a(n),J

*     Set correct scale
      Q2=Q**2d0
      
*     Evolved PDF interpolation
      IF ( X.LT.XPDFMIN .OR. X.GT.XPDFMAX ) THEN
         WRITE(6,2000) 
 2000    FORMAT (2X,'PARTON INTERPOLATION: X OUT OF RANGE -- STOP')
         write(6,*) "X= ",X," XMAX, XMIN = ",XPDFMAX,XPDFMIN
         STOP
      ENDIF
*
      IF ( Q2.LT.Q2MIN .OR. Q2.GT.Q2MAX ) THEN
         WRITE(6,2001) 
 2001    FORMAT (2X,'PARTON INTERPOLATION: Q2 OUT OF RANGE -- STOP')
         write(6,*) "Q2 ,Q2MIN, Q2MAX = ",Q2,Q2MIN,Q2MAX
         STOP
      ENDIF
        
      MINX = 1
      MAXX = NPX+1
 10   CONTINUE
      MIDX = (MINX+MAXX)/2
      IF(X.LT.XG(MIDX)) THEN
         MAXX=MIDX
      ELSE
         MINX=MIDX
      END IF
      IF((MAXX-MINX).GT.1) GO TO 10
      IX = MINX

      MINQ = 1
      MAXQ = NPQ2+1
 20   CONTINUE
      MIDQ = (MINQ+MAXQ)/2
      IF(Q2.LT.Q2G(MIDQ)) THEN
         MAXQ=MIDQ
      ELSE
         MINQ=MIDQ
      END IF
      IF((MAXQ-MINQ).GT.1) GO TO 20
      IQ2 = MINQ
    
      do I=1,M
         if(IX.ge.M/2.and.IX.le.(NPX-M/2)) IX1A(I) = IX - M/2 + I
         if(IX.lt.M/2) IX1A(I) = I
         if(IX.gt.(NPX-M/2)) IX1A(I) = (NPX - M) + I
         
         if(IX1A(I).le.0.or.IX1A(I).gt.NPX) then
            write(6,*) "Error in grids! "
            write(6,*) "I, IXIA(I) = ",I, IX1A(I)
            call exit(-10)
         endif
      enddo

      do J=1,N
         if(IQ2.ge.N/2.and.IQ2.le.(NPQ2-N/2)) IX2A(J) = IQ2 - N/2 + J
         if(IQ2.lt.N/2) IX2A(J) = J
         if(IQ2.gt.(NPQ2-N/2)) IX2A(J) = (NPQ2 - N) + J
         if(IX2A(J).le.0.or.IX2A(J).gt.NPQ2) then
            write(6,*) "Error in grids! "
            write(6,*) "J, IXIA(J) = ",J,IX2A(J)
            call exit(-10)
         endif
      enddo

      IF(X.LT.XCH)THEN
         X1=dlog(X)          
      ELSE
         X1=X
      ENDIF
      X2=dlog(Q2)

      KREP=KREPWRAP
      if(KREP.lt.0.or.KREP.gt.NREP) then
         write(6,*) "Invalid value for KREP = ",KREP
         call exit(-10)
      endif
      
      DO IPDF = -6,6,1
         
         DO I=1,M
            IF(X.LT.XCH)THEN
               X1A(I)= dlog(XG(IX1A(I)))
            ELSE
               X1A(I)= XG(IX1A(I))
            ENDIF
            DO J=1,N
               X2A(J) = dlog(Q2G(IX2A(J)))
               YA(I,J) = XPDFEV(IX1A(I),IX2A(J),IPDF,KREP)
            enddo
         enddo
         
         call polin2(x1a,x2a,ya,m,n,x1,x2,y,dy)
         XPDF(IPDF) = y
         
      enddo                 

      RETURN
      END

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      SUBROUTINE POLIN2(x1a,x2a,ya,m,n,x1,x2,y,dy) !Taken from NR
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT NONE

      INTEGER m,n,nmax,mmax
      INTEGER j,k
      PARAMETER(nmax=1e3,mmax=1e3)

      DOUBLE PRECISION dy,x1,x2,y,x1a(mmax),x2a(nmax),ya(mmax,nmax)
      DOUBLE PRECISION ymtmp(nmax),yntmp(nmax)

      DO j=1,m
         DO k=1,n
            yntmp(k)=ya(j,k)
         ENDDO
         CALL POLINT(x2a,yntmp,n,x2,ymtmp(j),dy)
      ENDDO
      CALL POLINT(x1a,ymtmp,m,x1,y,dy)

      RETURN
      END

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      SUBROUTINE POLINT(xa,ya,n,x,y,dy)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT NONE

      INTEGER n,NMAX
      PARAMETER(nmax=1e3)
      DOUBLE PRECISION dy,x,y,xa(nmax),ya(nmax)     
      INTEGER i,m,ns
      DOUBLE PRECISION den,dif,dift,ho,hp,w,c(nmax),d(nmax)
      ns=1
      dif=abs(x-xa(1))
      do 11 i=1,n
         dift=abs(x-xa(i))
         if(dift.lt.dif) then
            ns=i
            dif=dift
         endif
         c(i)=ya(i)
         d(i)=ya(i)
 11   enddo
      y=ya(ns)
      ns=ns-1
      do m=1,n-1
         do i=1,n-m
            ho=xa(i)-x
            hp=xa(i+m)-x
            w=c(i+1)-d(i)
            den=ho-hp
            if(den.eq.0) then
               write (*,*) 'failure in polint'
               read(5,*)
            endif
            den=w/den
            d(i)=hp*den
            c(i)=ho*den
         enddo
         if(2*ns.lt.(n-m)) then
            dy=c(ns+1)
         else
            dy=d(ns)
            ns=ns-1
         endif
         y=y+dy
      enddo

      return
      end

      INTEGER FUNCTION JISEARCH(N,X,Y) 
                                                                       
      IMPLICIT DOUBLE PRECISION(A-H,O-Z) 
!     Dynamical memory allocation                                       
      DOUBLE PRECISION X(*) 
                                                                       
      MIN=1 
      MAX=N+1 
                                                                       
   10 CONTINUE 
      MID=(MIN+MAX)/2 
      IF(Y.LT.X(MID)) THEN 
        MAX=MID 
      ELSE 
        MIN=MID 
      END IF 
      IF((MAX-MIN).GT.1) GOTO 10 
                                                                       
      JISEARCH=MIN 
                                                                       
      RETURN 
      END                                           

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      SUBROUTINE INITNNPDF(IREP)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT NONE

      INTEGER MXREP,NREP, IREP
      PARAMETER(MXREP=1e3)
      common/CNREP/NREP
      INTEGER KREPWRAP
      common/CKREPWRAP/KREPWRAP

      if(IREP.lt.0.or.IREP.gt.NREP) then
         write(6,*) "Invalid value for IREP in initNNPDF = ",
     1        IREP, NREP
         call exit(-10)
      endif

      KREPWRAP = IREP

      RETURN
      END

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      SUBROUTINE NUMBERNNPDF(NMEM)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT NONE

      INTEGER MXREP,NREP,NMEM
      PARAMETER(MXREP=1e3)
      common/CNREP/NREP

      NMEM = NREP

      if(NMEM.lt.0.or.NMEM.gt.MXREP) then
         write(6,*) "Invalid number of replicas"
         call exit(-10)
      endif

      RETURN
      END

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      SUBROUTINE INITNNPDFSET(wrapfile)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT NONE
      
      INTEGER MXREP,NREP,I
      PARAMETER(MXREP=1e3)
      common/CNREP/NREP

      INTEGER NPX,NPQ2,NPL,IX,IQ2
      PARAMETER(NPX=100,NPQ2=50)
      PARAMETER(NPL=5000)

      INTEGER IPDF,ILINES,NXTMP,NQ2TMP
      INTEGER NLINES,IDUM,IREP
      INTEGER NSET,IDEF

      DOUBLE PRECISION Q2MIN,Q2MAX,XPDFMIN,XPDFMAX,XCH,Q2CH
      DOUBLE PRECISION QREF, QTH(3:6), ASREF, DBDUM
      PARAMETER(Q2MAX=1d5,Q2CH=4d0)
      PARAMETER(XPDFMIN=1d-5,XPDFMAX=1d0,XCH=1D-1)

      DOUBLE PRECISION XG(NPX),Q2G(NPQ2)
      DOUBLE PRECISION XPDFEV(NPX,NPQ2,-6:6,0:MXREP)
      common/CPDFGR/XPDFEV,XG,Q2G,Q2MIN,IX,IQ2
      DOUBLE PRECISION mc,mb,mt,Q_ASREF
      DOUBLE PRECISION ALPHAS(0:MXREP),Q20
      common/CLHAPARS/ALPHAS,Q_ASREF,mc,mb,mt,Q20
      CHARACTER*10 FLVSCHM,PTORDC
      common/CEVOLCHAR/FLVSCHM,PTORDC
     
      DOUBLE PRECISION XMINTMP,XMAXTMP,Q2MINTMP,Q2MAXTMP
      DOUBLE PRECISION ADUM, LAMBDA4, LAMBDA5

      CHARACTER*70 wrapfile
      CHARACTER*33 path
      CHARACTER*50 char1, char2, char3
      CHARACTER*70 char

      LOGICAL VERBOSE

      VERBOSE=.true.

      open(unit=10,status="old",file=wrapfile(1:70))

      do i=1,13
         read(10,*) char
         if(i.gt.2)then
            write(6,*) char
         endif
      enddo

      read(10,*) char

      read(10,*) char
      read(10,*) idum, qREF, qth(4), qth(5), qth(6)

      read(10,*) char
      read(10,*) nset, idef
      read(10,*) XMINTMP,XMAXTMP,Q2MINTMP,Q2MAXTMP

      if(Q2MAX.ne.Q2MAXTMP) then
         write(6,*) "Mismatch, Q2MAX = ",Q2MAX, Q2MAXTMP
         call exit(-10)
      endif
      if(XPDFMAX.ne.XMAXTMP) then
         write(6,*) "Mismatch, XPDFMAX = ",XPDFMAX, XMAXTMP
         call exit(-10)
      endif
      if(XPDFMIN.ne.XMINTMP) then
         write(6,*) "Mismatch, XPDFMIN = ",XPDFMIN, XMINTMP
         call exit(-10)
      endif

      read(10,*) char
      read(10,*) nset, idef
      read(10,*) lambda4, lambda5

      read(10,*) char
      read(10,*) char, nrep, idum

      do I=0, NREP
         read(10,*) asref
      enddo

      read(10,*) char
      read(10,*) char
      read(10,*) char

      read(10,*) NSET, idef

 442  format(a,f12.3,1x,f12.3,1x,f12.2)
      
      read(10,*) NXTMP
      if(NXTMP.ne.NPX) then
         write(6,*) "Invalid value of NX!"
         call exit(-10)
      endif
      do IX=1,NPX
         read(10,*) XG(IX)
      enddo

      read(10,*) NQ2TMP
      if(NQ2TMP.ne.NPQ2) then
         write(6,*) "Invalid value of NQ2!"
         call exit(-10)
      endif
      read(10,*) dbdum
      do IQ2=1,NPQ2
         read(10,*) Q2G(IQ2)
      enddo

      write(6,*) "Initializing the NNPDF polarized grid. Please wait"

      if(wrapfile(1:5).ne."toyLH") then

      read(10,*) NREP
         do IREP=0,NREP
            do IX=1,NPX
               do IQ2=1,NPQ2
                  read(10,*) ( XPDFEV(IX,IQ2,IPDF,IREP), IPDF=-6,6,1 )
               enddo
            enddo
         enddo
      elseif(wrapfile(1:5).eq."toyLH") then
         IREP=0
         do IX=1,NPX
            do IQ2=1,NPQ2
               read(10,*) ( XPDFEV(IX,IQ2,IPDF,IREP), IPDF=-6,6,1 )
            enddo
         enddo
      else
         write(6,*) "Invalid wrapper type!"
         call exit(-10)
      endif

      read(10,*) char
      if(char.ne."End:")then
         write(6,*) "An error occurred when initializing NNPDF grids"
         call exit(-10)
      endif

      close(10)

      write(6,*) "Successful initialization of NNPDF polarized grid"
      

      return
      end





 

 

 





 










 




